@@ -19,26 +19,31 @@
 */
 
 #include "infoview.h"
-#include "abstractwindowinterface.h"
-#include "dock/panelshadows_p.h"
 
+// local
+#include <config-latte.h>
+#include "wm/abstractwindowinterface.h"
+#include "view/panelshadows_p.h"
+
+// Qt
 #include <QQuickItem>
 #include <QQmlContext>
 #include <QQmlEngine>
 #include <QScreen>
 
+// KDE
 #include <KLocalizedContext>
 #include <KDeclarative/KDeclarative>
-
-#include <Plasma/Package>
 #include <KWindowSystem>
-
 #include <KWayland/Client/plasmashell.h>
 #include <KWayland/Client/surface.h>
 
+// Plasma
+#include <Plasma/Package>
+
 namespace Latte {
 
-InfoView::InfoView(DockCorona *corona, QString message, QScreen *screen, QWindow *parent)
+InfoView::InfoView(Latte::Corona *corona, QString message, QScreen *screen, QWindow *parent)
     : QQuickView(parent),
       m_corona(corona),
       m_message(message),
@@ -77,7 +82,13 @@ void InfoView::init()
     KDeclarative::KDeclarative kdeclarative;
     kdeclarative.setDeclarativeEngine(engine());
     kdeclarative.setTranslationDomain(QStringLiteral("latte-dock"));
+#if KF5_VERSION_MINOR >= 45
+    kdeclarative.setupContext();
+    kdeclarative.setupEngine(engine());
+#else
     kdeclarative.setupBindings();
+#endif
+
     auto source = QUrl::fromLocalFile(m_corona->kPackage().filePath("infoviewui"));
     setSource(source);
 
@@ -119,7 +130,7 @@ void InfoView::showEvent(QShowEvent *ev)
 {
     QQuickWindow::showEvent(ev);
 
-    m_corona->wm()->setDockExtraFlags(*this);
+    m_corona->wm()->setViewExtraFlags(*this);
     setFlags(wFlags());
 
     m_corona->wm()->enableBlurBehind(*this);
@@ -141,7 +152,7 @@ void InfoView::setupWaylandIntegration()
 
     if (m_corona) {
         using namespace KWayland::Client;
-        PlasmaShell *interface = m_corona->waylandDockCoronaInterface();
+        PlasmaShell *interface = m_corona->waylandCoronaInterface();
 
         if (!interface) {
             return;
